pub struct UnitSpawnUnit {
pub unit_hex: Hex,
pub body: UnitBody,
pub name: String,
pub out: Option<Vec<Hex>>,
}Expand description
The spawning of a unit from a unit
Fields
unit_hex: Hexbody: UnitBodyname: Stringout: Option<Vec<Hex>>If out hexes are not provided the engine will choose the first empty one in a clockwise direction If out hexes are provided, sucessfully spawned units will be outputed to the first empty hex